package envoy.server.processors;

import java.io.IOException;
import java.util.stream.Collectors;

import envoy.data.Contacts;
import envoy.event.ContactSearchRequest;
import envoy.event.ContactSearchResult;
import envoy.server.data.PersistenceManager;
import envoy.server.data.User;
import envoy.server.net.ConnectionManager;
import envoy.server.net.ObjectWriteProxy;

/**
 * Project: <strong>envoy-server-standalone</strong><br>
 * File: <strong>ContactsRequestEventProcessor.java</strong><br>
 * Created: <strong>08.02.2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @author Maximilian K&auml;fer
 * @since Envoy Server Standalone v0.1-alpha
 */
public class ContactsRequestEventProcessor implements ObjectProcessor<ContactSearchRequest> {

	/**
	 * Writes a {@link Contacts} list to the client containing all {@link User}s
	 * matching the search phrase contained inside the request. The client and their
	 * contacts are excluded from the result.
	 *
	 * @since Envoy Server Standalone v0.1-alpha
	 */
	@Override
	public void process(ContactSearchRequest request, long socketId, ObjectWriteProxy writeProxy) throws IOException {
		writeProxy.write(socketId,
				new ContactSearchResult(PersistenceManager.getInstance()
					.searchUsers(request.get(), ConnectionManager.getInstance().getUserIdBySocketId(socketId))
					.stream()
					.map(User::toCommonUser)
					.collect(Collectors.toList())));
	}

	@Override
	public Class<ContactSearchRequest> getInputClass() { return ContactSearchRequest.class; }
}
